# swagger_client.ProjectsApi

All URIs are relative to *https://platform.its4land.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**add_tag_to_project**](ProjectsApi.md#add_tag_to_project) | **POST** /projects/{project_uid}/Tags | Adds a tag to the project
[**del_project_by_uid**](ProjectsApi.md#del_project_by_uid) | **DELETE** /projects/{project_uid} | Deletes a single e project by its UID
[**detach_project_model**](ProjectsApi.md#detach_project_model) | **DELETE** /projects/{project_uid}/Models/{model_uid} | Removes a model from a project.
[**detach_project_spatial_source**](ProjectsApi.md#detach_project_spatial_source) | **DELETE** /projects/{project_uid}/SpatialSources/{spatialsource_uid} | Removes a spatialsource from a project.
[**detach_project_tag**](ProjectsApi.md#detach_project_tag) | **DELETE** /projects/{project_uid}/Tags/{tag} | Removes a tag from a project.
[**get_connected_objects_by_project_uid**](ProjectsApi.md#get_connected_objects_by_project_uid) | **GET** /projects/{project_uid}/connectedObjects | Returns an array of connect objects
[**get_models_by_project_uid**](ProjectsApi.md#get_models_by_project_uid) | **GET** /projects/{project_uid}/Models | Returns the models of a project
[**get_project_tags_by_project_uid**](ProjectsApi.md#get_project_tags_by_project_uid) | **GET** /projects/{project_uid}/Tags | Returns the tags of a project.
[**get_projects**](ProjectsApi.md#get_projects) | **GET** /projects | Get a GeoJSON structure containing a list of Projects.
[**get_projects_by_uid**](ProjectsApi.md#get_projects_by_uid) | **GET** /projects/{project_uid} | Getting single Projects by its UID
[**get_spatial_source_by_project_uid**](ProjectsApi.md#get_spatial_source_by_project_uid) | **GET** /projects/{project_uid}/SpatialSources | Returns the SpatialSources of a Project.
[**new_model_under_project**](ProjectsApi.md#new_model_under_project) | **POST** /projects/{project_uid}/Models | Create a new model
[**new_project**](ProjectsApi.md#new_project) | **POST** /projects | Create a new project
[**new_spatial_source_under_project**](ProjectsApi.md#new_spatial_source_under_project) | **POST** /projects/{project_uid}/SpatialSources | Create a new SpatialSource
[**update_projects**](ProjectsApi.md#update_projects) | **PATCH** /projects/{project_uid} | Update a project


# **add_tag_to_project**
> ProjectsEndpointType add_tag_to_project(project_uid, newtag, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)

Adds a tag to the project

Creates a new tag and attach it to the project. If the tag already exist, the existing tag will be attached to the project.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
newtag = swagger_client.TagsPostRequest() # TagsPostRequest | New Tag data
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)
i4l_process_uid = 'i4l_process_uid_example' # str | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional)

try:
    # Adds a tag to the project
    api_response = api_instance.add_tag_to_project(project_uid, newtag, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->add_tag_to_project: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **newtag** | [**TagsPostRequest**](TagsPostRequest.md)| New Tag data | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4l_process_uid** | **str**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **del_project_by_uid**
> ProjectsEndpointType del_project_by_uid(project_uid, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)

Deletes a single e project by its UID

A single project is deleted. This endpoint deletes the project itself and the connected to subordered data like SpatialSources, etc. The subordered data itself are not deleted

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | UID of the project
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)
i4l_process_uid = 'i4l_process_uid_example' # str | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional)

try:
    # Deletes a single e project by its UID
    api_response = api_instance.del_project_by_uid(project_uid, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->del_project_by_uid: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| UID of the project | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4l_process_uid** | **str**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **detach_project_model**
> ProjectsEndpointType detach_project_model(project_uid, model_uid, envelope=envelope, force_delete=force_delete)

Removes a model from a project.

Removes a model from a project. By default only the link between model and project is removed.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
model_uid = 'model_uid_example' # str | Model UID
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
force_delete = 'force_delete_example' # str | Deletes the model resource. ********* What's about subordinate resources? ********* (optional)

try:
    # Removes a model from a project.
    api_response = api_instance.detach_project_model(project_uid, model_uid, envelope=envelope, force_delete=force_delete)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->detach_project_model: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **model_uid** | **str**| Model UID | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **force_delete** | **str**| Deletes the model resource. ********* What&#39;s about subordinate resources? ********* | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **detach_project_spatial_source**
> ProjectsEndpointType detach_project_spatial_source(project_uid, spatialsource_uid, force_delete=force_delete)

Removes a spatialsource from a project.

Removes a spatial from a project. By default only the link between spatialsource and project is removed.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
spatialsource_uid = 'spatialsource_uid_example' # str | SpatialSource UID
force_delete = 'force_delete_example' # str | Deletes the spatialsource resource. ********* What's about subordinate resources? ********* (optional)

try:
    # Removes a spatialsource from a project.
    api_response = api_instance.detach_project_spatial_source(project_uid, spatialsource_uid, force_delete=force_delete)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->detach_project_spatial_source: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **spatialsource_uid** | **str**| SpatialSource UID | 
 **force_delete** | **str**| Deletes the spatialsource resource. ********* What&#39;s about subordinate resources? ********* | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **detach_project_tag**
> ProjectsEndpointType detach_project_tag(project_uid, tag, envelope=envelope, force_delete=force_delete)

Removes a tag from a project.

Removes a tag from a project. By default only the link between tag and project is removed.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
tag = 'tag_example' # str | tag value
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
force_delete = 'force_delete_example' # str | Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. ********* (optional)

try:
    # Removes a tag from a project.
    api_response = api_instance.detach_project_tag(project_uid, tag, envelope=envelope, force_delete=force_delete)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->detach_project_tag: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **tag** | **str**| tag value | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **force_delete** | **str**| Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. ********* | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_connected_objects_by_project_uid**
> ConnectedObjectsEndpointType get_connected_objects_by_project_uid(project_uid, envelope=envelope, page=page, sort=sort, fields=fields, embed=embed)

Returns an array of connect objects

Returns an array of connect objects of a project. For each connected object the endpoint returns the type, name and uuid

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
page = 56 # int | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional)
sort = 'sort_example' # str | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional)
fields = ['fields_example'] # list[str] | Comma separated list of field names (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)

try:
    # Returns an array of connect objects
    api_response = api_instance.get_connected_objects_by_project_uid(project_uid, envelope=envelope, page=page, sort=sort, fields=fields, embed=embed)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->get_connected_objects_by_project_uid: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **int**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **str**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**list[str]**](str.md)| Comma separated list of field names | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**ConnectedObjectsEndpointType**](ConnectedObjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_models_by_project_uid**
> list[ModelsEndpointType] get_models_by_project_uid(project_uid, envelope=envelope, page=page, sort=sort, fields=fields, embed=embed)

Returns the models of a project

Returns the models of a project

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
page = 56 # int | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional)
sort = 'sort_example' # str | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional)
fields = ['fields_example'] # list[str] | Comma separated list of field names (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)

try:
    # Returns the models of a project
    api_response = api_instance.get_models_by_project_uid(project_uid, envelope=envelope, page=page, sort=sort, fields=fields, embed=embed)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->get_models_by_project_uid: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **int**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **str**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**list[str]**](str.md)| Comma separated list of field names | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**list[ModelsEndpointType]**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_project_tags_by_project_uid**
> TagsListResponse get_project_tags_by_project_uid(project_uid, envelope=envelope)

Returns the tags of a project.

Is this method really necessary? Returns the tags of a project.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)

try:
    # Returns the tags of a project.
    api_response = api_instance.get_project_tags_by_project_uid(project_uid, envelope=envelope)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->get_project_tags_by_project_uid: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 

### Return type

[**TagsListResponse**](TagsListResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_projects**
> ProjectsEndpointType get_projects(envelope=envelope, uid=uid, name=name, aoi=aoi, tags=tags, page=page, sort=sort, fields=fields, embed=embed)

Get a GeoJSON structure containing a list of Projects.

Get a GeoJSON structure containing a list of Projects. A single project is modeled as a GeoJSON feature.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
uid = ['uid_example'] # list[str] | Comma separated list of UID (optional)
name = ['name_example'] # list[str] | Comma separated list of names (optional)
aoi = 'aoi_example' # str | Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1 (optional)
tags = ['tags_example'] # list[str] | Comma separated list of tags (optional)
page = 56 # int | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional)
sort = 'sort_example' # str | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional)
fields = ['fields_example'] # list[str] | Comma separated list of field names (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)

try:
    # Get a GeoJSON structure containing a list of Projects.
    api_response = api_instance.get_projects(envelope=envelope, uid=uid, name=name, aoi=aoi, tags=tags, page=page, sort=sort, fields=fields, embed=embed)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->get_projects: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **uid** | [**list[str]**](str.md)| Comma separated list of UID | [optional] 
 **name** | [**list[str]**](str.md)| Comma separated list of names | [optional] 
 **aoi** | **str**| Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1 | [optional] 
 **tags** | [**list[str]**](str.md)| Comma separated list of tags | [optional] 
 **page** | **int**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **str**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**list[str]**](str.md)| Comma separated list of field names | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_projects_by_uid**
> ProjectsEndpointType get_projects_by_uid(project_uid, envelope=envelope, embed=embed)

Getting single Projects by its UID

Getting single Projects by its UID. The project is modeled as a feature in a GeoJSON structure.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | UID of the project
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)

try:
    # Getting single Projects by its UID
    api_response = api_instance.get_projects_by_uid(project_uid, envelope=envelope, embed=embed)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->get_projects_by_uid: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| UID of the project | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_spatial_source_by_project_uid**
> list[SpatialSourcesEndpointType] get_spatial_source_by_project_uid(project_uid, envelope=envelope, page=page, sort=sort, fields=fields, embed=embed)

Returns the SpatialSources of a Project.

Returns the SpatialSources of a Project.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
page = 56 # int | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. (optional)
sort = 'sort_example' # str | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. (optional)
fields = ['fields_example'] # list[str] | Comma separated list of field names (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)

try:
    # Returns the SpatialSources of a Project.
    api_response = api_instance.get_spatial_source_by_project_uid(project_uid, envelope=envelope, page=page, sort=sort, fields=fields, embed=embed)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->get_spatial_source_by_project_uid: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **int**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **str**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**list[str]**](str.md)| Comma separated list of field names | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 

### Return type

[**list[SpatialSourcesEndpointType]**](SpatialSourcesEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **new_model_under_project**
> ProjectsEndpointType new_model_under_project(project_uid, newmodel, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)

Create a new model

Create a new model.  To add a new Model , the content of Models  must be stored in advanced via the ContentItem endpoint

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
newmodel = swagger_client.ModelsPostRequest() # ModelsPostRequest | New model data
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)
i4l_process_uid = 'i4l_process_uid_example' # str | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional)

try:
    # Create a new model
    api_response = api_instance.new_model_under_project(project_uid, newmodel, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->new_model_under_project: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **newmodel** | [**ModelsPostRequest**](ModelsPostRequest.md)| New model data | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4l_process_uid** | **str**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **new_project**
> ProjectsEndpointType new_project(newproject, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)

Create a new project

Create a new project. The new project is modeled as a feature in a GeoJSON structure. Currently only one project feature is allowed.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
newproject = swagger_client.ProjectsPostRequest() # ProjectsPostRequest | New project data
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)
i4l_process_uid = 'i4l_process_uid_example' # str | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional)

try:
    # Create a new project
    api_response = api_instance.new_project(newproject, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->new_project: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newproject** | [**ProjectsPostRequest**](ProjectsPostRequest.md)| New project data | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4l_process_uid** | **str**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **new_spatial_source_under_project**
> ProjectsEndpointType new_spatial_source_under_project(project_uid, newspatialsource, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)

Create a new SpatialSource

Create a new SpatialSource. To add a new SpatialSource , the content of SpatialSource  must be stored in advanced via the ContentItem endpoint

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID
newspatialsource = swagger_client.SpatialSourcesPostRequest() # SpatialSourcesPostRequest | New SpatialSource data
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)
i4l_process_uid = 'i4l_process_uid_example' # str | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional)

try:
    # Create a new SpatialSource
    api_response = api_instance.new_spatial_source_under_project(project_uid, newspatialsource, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->new_spatial_source_under_project: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID | 
 **newspatialsource** | [**SpatialSourcesPostRequest**](SpatialSourcesPostRequest.md)| New SpatialSource data | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4l_process_uid** | **str**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_projects**
> ProjectsEndpointType update_projects(project_uid, patchproject, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)

Update a project

Updates some attributes of a project.

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.ProjectsApi()
project_uid = 'project_uid_example' # str | Project UID to be patched
patchproject = swagger_client.RFC6902PatchRequest() # RFC6902PatchRequest | Update data
envelope = 'envelope_example' # str | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. (optional)
embed = ['embed_example'] # list[str] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) (optional)
i4l_process_uid = 'i4l_process_uid_example' # str | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. (optional)

try:
    # Update a project
    api_response = api_instance.update_projects(project_uid, patchproject, envelope=envelope, embed=embed, i4l_process_uid=i4l_process_uid)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ProjectsApi->update_projects: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **project_uid** | **str**| Project UID to be patched | 
 **patchproject** | [**RFC6902PatchRequest**](RFC6902PatchRequest.md)| Update data | 
 **envelope** | **str**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**list[str]**](str.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4l_process_uid** | **str**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

